
From: Nick Piggin <piggin@cyberone.com.au>

Here are a few changes for mm4. There are IPSEC and NFS items which
I think might be fixed but I'm not quite sure. Probably others as well.
Are the psmouse problems fixed? Are all the drivers (video, irda, etc)
really must fix items?



 Documentation/must-fix.txt   |   43 +--------------------------------
 Documentation/should-fix.txt |   55 ++++++++++++++++++++++++++++++++-----------
 2 files changed, 44 insertions(+), 54 deletions(-)

diff -puN Documentation/must-fix.txt~must-fix-update-2 Documentation/must-fix.txt
--- 25/Documentation/must-fix.txt~must-fix-update-2	2003-11-19 01:07:06.000000000 -0800
+++ 25-akpm/Documentation/must-fix.txt	2003-11-19 01:07:06.000000000 -0800
@@ -110,20 +110,7 @@ o Lots of drivers don't compile, others 
 drivers/scsi/
 ~~~~~~~~~~~~~
 
-o hch: large parts of the locking are hosed or not existant
-
-  (Mike Anderson, Patrick Mansfield, Badari Pulavarty)
-
-  o shost->my_devices isn't locked down at all
-
-  o there are lots of members of struct Scsi_Host/scsi_device/scsi_cmnd
-    with very unclear locking, many of them probably want to become
-    atomic_t's or bitmaps (for the 1bit bitfields).
-
-  o there's lots of volatile abuse in the scsi code that needs to be
-    thought about.
-
-  o there's some global variables incremented without any locks
+o hch: shost->my_devices isn't locked down at all
 
 o Convert am53c974, dpt_i2o, initio and pci2220i to DMA-mapping
 
@@ -160,12 +147,6 @@ fs/
 o AIO/direct-IO writes can race with truncate and wreck filesystems.
   (Badari has a patch)
 
-o hch: devfs: there's a fundamental lookup vs devfsd race that's only
-  fixable by introducing a lookup vs devfs deadlock.  I can't see how this is
-  fixable without getting rid of the current devfsd design.  Mandrake seems
-  to have a workaround for this so this is at least not triggered so easily,
-  but that's not what I'd consider a fix..
-
 o viro: fs/char_dev.c needs removal of aeb stuff and merge of cdev-cidr.
   In progress.
 
@@ -292,34 +273,14 @@ o Module relationship bogosity fix (triv
 sound/
 ~~~~~~
 
-o rmk: several OSS drivers for SA11xx-based hardware in need of
-  ALSA-ification and L3 bus support code for these.
-
-o rmk: linux/sound/drivers/mpu401/mpu401.c and
-  linux/sound/drivers/virmidi.c complained about 'errno' at some time in the
-  past, need to confirm whether this is still a problem.
-
-o rmk: need to complete ALSA-ification of the WaveArtist driver for both
-  NetWinder and other stuff (there's some fairly fundamental differences in
-  the way the mixer needs to be handled for the NetWinder.)
-
-
-  (Issues with forward-porting 2.4 bugfixes.)
-  (Killing off OSS is 2.7 material)
-
-
 global
 ~~~~~~
 
-o alan, Albert Cahalan: 1000 HZ timer increases the need for a stable time
-  source. Many laptops, SMI can lose ticks. ACPI timers? TSC?
-
 o viro: 64-bit dev_t (not a mustfix for 2.6.0). 32-bit dev_t is done, 64-bit
   means extra work on nfsd/raid/etc.
 
 o alan: Forward port 2.4 fixes
-  - Security fixes including execve holes, execve vs proc races
-  - SiS IRQ routing for newer SiS and older Intel
+  - Chris Wright: Security fixes including execve holes, execve vs proc races
 
 o There are about 60 or 70 security related checks that need doing
   (copy_user etc) from Stanford tools.  (badari is looking into this, and
diff -puN Documentation/should-fix.txt~must-fix-update-2 Documentation/should-fix.txt
--- 25/Documentation/should-fix.txt~must-fix-update-2	2003-11-19 01:07:06.000000000 -0800
+++ 25-akpm/Documentation/should-fix.txt	2003-11-19 01:07:06.000000000 -0800
@@ -151,6 +151,16 @@ o aio: fs IO isn't async at present.  su
 
 o drepper: various filesystems use ->pid wrongly
 
+  PRI1
+
+o hch: devfs: there's a fundamental lookup vs devfsd race that's only
+  fixable by introducing a lookup vs devfs deadlock.  I can't see how this is
+  fixable without getting rid of the current devfsd design.  Mandrake seems
+  to have a workaround for this so this is at least not triggered so easily,
+  but that's not what I'd consider a fix..
+
+  PRI2
+
 kernel/
 ~~~~~~~
 
@@ -187,10 +197,6 @@ o klibc merge?
 mm/
 ~~~
 
-o oxymoron's async write-error-handling patch
-
-  PRI1
-
 o dropbehind for large files
 
   PRI2
@@ -429,6 +435,38 @@ o jejb: qlogic -
 
   PRI2
 
+o hch, Mike Anderson, Badari Pulavarty: scsi locking issues
+
+  o there are lots of members of struct Scsi_Host/scsi_device/scsi_cmnd
+    with very unclear locking, many of them probably want to become
+    atomic_t's or bitmaps (for the 1bit bitfields).
+
+  o there's lots of volatile abuse in the scsi code that needs to be
+    thought about.
+
+  o there's some global variables incremented without any locks
+
+  PRI2
+
+sound/
+~~~~~~
+
+o rmk: several OSS drivers for SA11xx-based hardware in need of
+  ALSA-ification and L3 bus support code for these.
+
+o rmk: linux/sound/drivers/mpu401/mpu401.c and
+  linux/sound/drivers/virmidi.c complained about 'errno' at some time in the
+  past, need to confirm whether this is still a problem.
+
+o rmk: need to complete ALSA-ification of the WaveArtist driver for both
+  NetWinder and other stuff (there's some fairly fundamental differences in
+  the way the mixer needs to be handled for the NetWinder.)
+
+  (Issues with forward-porting 2.4 bugfixes.)
+  (Killing off OSS is 2.7 material)
+
+PRI2
+
 arch/i386/
 ~~~~~~~~~~
 
@@ -457,15 +495,6 @@ o 2.5.x doesn't handle VIA APIC right ye
 
   PRI1
 
-o ACPI needs the relax patches merging to work on lots of laptops
-
-  alan: ACPI relax stuff is in 2.4-ac, compaq workaround is in next -ac
-  coming.  These seem to deliver the goods - toshibas now work a treat.  Some
-  other relax bits are being discussed (assume local0 starts 0 etc) and
-  progress looks great.  This can occur before 2.6 or during.
-
-  PRI1
-
 o ECC driver questions are not yet sorted (DaveJ is working on this) (Dan
   Hollis)
 

_
